@@ -45,8 +45,6 @@ Sjis-JA - Source code filter to escape ShiftJIS (Japanese document)
       Perl5.6 G~[V(perl5.005̏ꍇ)
         use warnings;
         use warnings::register;
-        binmode(...);
-        open(...);
 
       ȉ̓_~[֐Ƃ
         utf8::upgrade(...);
@@ -85,8 +83,8 @@ jperl ͕svɂȂƌĂ܂B
 
 {ɂāAėp^Rs[^̓óAp[\iRs[^̓R[
 hѓóAɂ͌gѓdbɎ܂ŁAShiftJIS {ƂR[h
-LgĂ܂B̃\tgEFA͂ ShiftJIS 𒼐ڈ܂B̂
-UTF8 tO͂܂B
+LgĂ܂B̃\tgEFA͂ ShiftJIS 𒼐ڈ܂B
+Latin-1 ܂B̂ UTF8 tO͂܂B
 ̃\tgEFA Shift_JIS, Windows-31J, CP932, MacJapanese, SJIS(R90),
 Shift_JISX0213, Shift_JIS-2004 Ȃǂ ShiftJIS ̈Ƃł܂B
 ̕ł͂𑍏̂ ShiftJIS Ƃŕ\Ă܂(u_vȂ)B
@@ -94,7 +92,7 @@ Shift_JISX0213, Shift_JIS-2004 Ȃǂ ShiftJIS ̈Ƃł܂B
 Gȉ@͖蕡Gɂ܂B
 ȂGR[h̖肩GXP[v܂񂩁H
 
-=head1 ЂƂ̖
+=head1 ЂƂ̖(݂炢)
 
 JPerl ͂ƂĂDꂽ\tgEFAłBƁAł JPerl ͓{Ήł
 Perl ̂ƂŁAJava  JVM Ƃ͊֌W܂BȂ킯ŁÃ\tgEFA
@@ -126,17 +124,17 @@ ftp://ftp.oreilly.co.jp/pcjp98/watanabe/jperlconf.ppt
 
 =over 2
 
-=item * ShiftJIS ̂܂܂̒l
+=item * Perl4  Perl5 ̂悤ȏʌ݊
 
-=item * ߋ̃f[^AXNvgAmEnEƌ݊ۂĂ
+=item * jcode.pl ̂悤ȍő̈ڐA
 
-=item * UNIXOSADOSOS̏ꍇ́ASjis.pm  Esjis.pm ŋ@\
+=item * JPerl ̂悤ɃVtgJIŜ܂܈AUTF8tOȂ
 
-=item * UTF8 tOȂł(perlunitut  perluniadvice ̑Ή͕sv)
+=item * Encode W[̂悤 Perl 1̃C^v^̂܂
 
-=item * (JPerlێ炷邽߂) C vO~OsȂł
+=item * Ruby ̂悤ɕWƗȎ@
 
-=item * (CPU, OS, perl̃o[W, 32rbg/64rbgł̈Ⴂɂ) oCit@CɈˑȂ
+=item * Perl ĝ悤 TMTOWTDI(There's more than one way to do it)
 
 =back
 
@@ -222,8 +220,9 @@ GXP[v_قȂ܂B
 =head1 GXP[vɂʌ݊̊m
 
 ̃\tgEFA͉ߋ̂̂󂵂͂AɁuGXP[vvɂċ@\ǉ
-Ă܂B獡܂ŉ\łƂs\ɂȂ邱Ƃ͂܂B
-̃Av[`́AނċȂɗLłB
+Ă܂B獡܂ŉ\łƂs\ɂȂ邱Ƃ͂܂B̃Av
+[`́AނċȂɗLłBȂAʌ݊̊mۂ̂߂ɂ́A
+܂łPerlƔ݊Ȋg͎菜Ƃ܂B
 
 =head1 XNvg̃GXP[v
 
@@ -287,18 +286,57 @@ GXP[v_قȂ܂B
   ---------------------------------------------------------------------------
   escape        class
   ---------------------------------------------------------------------------
-   .            (?:[\x81-\x9F\xE0-\xFC][\x00-\xFF]|[^\x0A])
-                (?:[\x81-\x9F\xE0-\xFC][\x00-\xFF]|[\x00-\xFF]) (/s Cq)
+   .            (?:[\x81-\x9F\xE0-\xFC][\x00-\xFF]|[^\x81-\x9F\xE0-\xFC\x0A])
+                (?:[\x81-\x9F\xE0-\xFC][\x00-\xFF]|[^\x81-\x9F\xE0-\xFC])     (/s Cq)
   \d            [0-9]
   \s            [\x09\x0A\x0C\x0D\x20]
   \w            [0-9A-Z_a-z]
-  \D            (?:[\x81-\x9F\xE0-\xFC][\x00-\xFF]|[^0-9])
-  \S            (?:[\x81-\x9F\xE0-\xFC][\x00-\xFF]|[^\x09\x0A\x0C\x0D\x20])
-  \W            (?:[\x81-\x9F\xE0-\xFC][\x00-\xFF]|[^0-9A-Z_a-z])
+  \D            (?:[\x81-\x9F\xE0-\xFC][\x00-\xFF]|[^\x81-\x9F\xE0-\xFC0-9])
+  \S            (?:[\x81-\x9F\xE0-\xFC][\x00-\xFF]|[^\x81-\x9F\xE0-\xFC\x09\x0A\x0C\x0D\x20])
+  \W            (?:[\x81-\x9F\xE0-\xFC][\x00-\xFF]|[^\x81-\x9F\xE0-\xFC0-9A-Z_a-z])
   \h            [\x09\x20]
   \v            [\x0C\x0A\x0D]
-  \H            (?:[\x81-\x9F\xE0-\xFC][\x00-\xFF]|[^\x09\x20])
-  \V            (?:[\x81-\x9F\xE0-\xFC][\x00-\xFF]|[^\x0C\x0A\x0D])
+  \H            (?:[\x81-\x9F\xE0-\xFC][\x00-\xFF]|[^\x81-\x9F\xE0-\xFC\x09\x20])
+  \V            (?:[\x81-\x9F\xE0-\xFC][\x00-\xFF]|[^\x81-\x9F\xE0-\xFC\x0C\x0A\x0D])
+  \C            [\x00-\xFF]
+  \X            X (̉pAX ł)
+  \R            (?:\x0D\x0A|[\x0A\x0D])
+  \N            (?:[\x81-\x9F\xE0-\xFC][\x00-\xFF]|[^\x81-\x9F\xE0-\xFC\x0A])
+  ---------------------------------------------------------------------------
+
+l POSIX X^C̕NXĒ`Ă܂B
+
+  ---------------------------------------------------------------------------
+  escape        class
+  ---------------------------------------------------------------------------
+  [:alnum:]     [\x30-\x39\x41-\x5A\x61-\x7A]
+  [:alpha:]     [\x41-\x5A\x61-\x7A]
+  [:ascii:]     [\x00-\x7F]
+  [:blank:]     [\x09\x20]
+  [:cntrl:]     [\x00-\x1F\x7F]
+  [:digit:]     [\x30-\x39]
+  [:graph:]     [\x21-\x7F]
+  [:lower:]     [\x61-\x7A]
+  [:print:]     [\x20-\x7F]
+  [:punct:]     [\x21-\x2F\x3A-\x3F\x40\x5B-\x5F\x60\x7B-\x7E]
+  [:space:]     [\x09\x0A\x0B\x0C\x0D\x20]
+  [:upper:]     [\x41-\x5A]
+  [:word:]      [\x30-\x39\x41-\x5A\x5F\x61-\x7A]
+  [:xdigit:]    [\x30-\x39\x41-\x46\x61-\x66]
+  [:^alnum:]    (?:[\x81-\x9F\xE0-\xFC][\x00-\xFF]|[^\x81-\x9F\xE0-\xFC\x30-\x39\x41-\x5A\x61-\x7A])
+  [:^alpha:]    (?:[\x81-\x9F\xE0-\xFC][\x00-\xFF]|[^\x81-\x9F\xE0-\xFC\x41-\x5A\x61-\x7A])
+  [:^ascii:]    (?:[\x81-\x9F\xE0-\xFC][\x00-\xFF]|[^\x81-\x9F\xE0-\xFC\x00-\x7F])
+  [:^blank:]    (?:[\x81-\x9F\xE0-\xFC][\x00-\xFF]|[^\x81-\x9F\xE0-\xFC\x09\x20])
+  [:^cntrl:]    (?:[\x81-\x9F\xE0-\xFC][\x00-\xFF]|[^\x81-\x9F\xE0-\xFC\x00-\x1F\x7F])
+  [:^digit:]    (?:[\x81-\x9F\xE0-\xFC][\x00-\xFF]|[^\x81-\x9F\xE0-\xFC\x30-\x39])
+  [:^graph:]    (?:[\x81-\x9F\xE0-\xFC][\x00-\xFF]|[^\x81-\x9F\xE0-\xFC\x21-\x7F])
+  [:^lower:]    (?:[\x81-\x9F\xE0-\xFC][\x00-\xFF]|[^\x81-\x9F\xE0-\xFC\x61-\x7A])
+  [:^print:]    (?:[\x81-\x9F\xE0-\xFC][\x00-\xFF]|[^\x81-\x9F\xE0-\xFC\x20-\x7F])
+  [:^punct:]    (?:[\x81-\x9F\xE0-\xFC][\x00-\xFF]|[^\x81-\x9F\xE0-\xFC\x21-\x2F\x3A-\x3F\x40\x5B-\x5F\x60\x7B-\x7E])
+  [:^space:]    (?:[\x81-\x9F\xE0-\xFC][\x00-\xFF]|[^\x81-\x9F\xE0-\xFC\x09\x0A\x0B\x0C\x0D\x20])
+  [:^upper:]    (?:[\x81-\x9F\xE0-\xFC][\x00-\xFF]|[^\x81-\x9F\xE0-\xFC\x41-\x5A])
+  [:^word:]     (?:[\x81-\x9F\xE0-\xFC][\x00-\xFF]|[^\x81-\x9F\xE0-\xFC\x30-\x39\x41-\x5A\x5F\x61-\x7A])
+  [:^xdigit:]   (?:[\x81-\x9F\xE0-\xFC][\x00-\xFF]|[^\x81-\x9F\xE0-\xFC\x30-\x39\x41-\x46\x61-\x66])
   ---------------------------------------------------------------------------
 
 l \b  \B ߋperlƂ̌݊ۂ߂ɍĒ`Ă܂B
@@ -372,6 +410,26 @@ Esjis::* ֐ Esjis.pm 񋟂܂B
   bytes::substr    substr
   ------------------------------------
 
+=head1 \N, \p, \P, \X ̃AGXP[v
+
+̃\tgEFAɂĉp̐K\^V{ \N, \p, \P, \X ̐擪
+'\' 菜܂B̕@Œۉ㩂邱Ƃł܂B
+
+  ------------------------------------
+  O           
+  ------------------------------------
+  \N{CHARNAME}     N{CHARNAME}
+  \p{L}            p{L}
+  \p{^L}           p{^L}
+  \p{\^L}          p{\^L}
+  \pL              pL
+  \P{L}            P{L}
+  \P{^L}           P{^L}
+  \P{\^L}          P{\^L}
+  \PL              PL
+  \X               X
+  ------------------------------------
+
 =head1 t@CeXgZq̃GXP[v
 
 ̃\tgEFAɂĉZq '-'  'Esjis::' ɏ܂B
@@ -437,22 +495,18 @@ ẘ֐gꍇ͈ȉ̂悤ɋLqKv܂Bꂼ
 
 =item * Sjis::ord
 
-    "use Sjis qw(ord);" ɂ ord  Sjis::ord ɏ悤ɂȂ܂B
-
     $ord = Sjis::ord($string);
 
-    Sjis::ord($string)  $string ̐擪̕ ShiftJIS R[hlԂ܂B
-    $string ȗꂽꍇ $_ ΏۂƂȂ܂B̊֐͏ɕȂ
-    lԂ܂B
+    Sjis::ord($string)  $string ̐擪̕ ShiftJIS R[hlԂ܂
+    (Unicode ł͂܂)B$string ȗꂽꍇ $_ ΏۂƂȂ܂B
+    ̊֐͏ɕȂ̒lԂ܂B
 
-    ̓ JPerl Ɣ݊Ȃ̂ŖIɃC|[gꍇ̂݋@\悤
-    ȂĂ܂B
+    "use Sjis qw(ord);" ɂăXNvgɋLq ord  Sjis::ord ɏ
+    悤ɂȂ܂Bord  Sjis::ord ̓̂ JPerl Ɣ݊Ȃ
+    ŖIɃC|[gꍇ̂ݏ܂B
 
 =item * Sjis::reverse
 
-    "use Sjis qw(reverse);" ɂ reverse  Sjis::reverse ɏ悤
-    ɂȂ܂B
-
     @reverse = Sjis::reverse(@list);
     $reverse = Sjis::reverse(@list);
 
@@ -472,8 +526,9 @@ ẘ֐gꍇ͈ȉ̂悤ɋLqKv܂Bꂼ
     XJ[ReLXgł @list ׂ̂Ă̗vfAŁAShiftJIS 
     Pʂŋtɂ̂Ԃ܂B
 
-    ̓ JPerl Ɣ݊Ȃ̂ŖIɃC|[gꍇ̂݋@\悤
-    ȂĂ܂B
+    "use Sjis qw(reverse);" ɂăXNvgɋLq reverse 
+    Sjis::reverse ɏ悤ɂȂ܂Breverse  Sjis::reverse ̓
+    ̂ JPerl Ɣ݊Ȃ̂ŖIɃC|[gꍇ̂ݏ܂B
 
 =item * Sjis::length
 
@@ -587,8 +642,10 @@ WW[̃t@C /Perl/site/lib/Sjis ɃRs[ 'use utf8;'
   O                    
   -----------------------------------------------------------
   use strict;               use strict; no strict qw(refs);
+  use 5.12.0;               use 5.12.0; no strict qw(refs);
   require utf8;             # require utf8;
   require bytes;            # require bytes;
+  require charnames;        # require charnames;
   require I18N::Japanese;   # require I18N::Japanese;
   require I18N::Collate;    # require I18N::Collate;
   require I18N::JExt;       # require I18N::JExt;
@@ -598,6 +655,7 @@ WW[̃t@C /Perl/site/lib/Sjis ɃRs[ 'use utf8;'
   require Japanese;         # require Japanese;
   use utf8;                 # use utf8;
   use bytes;                # use bytes;
+  use charnames;            # use charnames;
   use I18N::Japanese;       # use I18N::Japanese;
   use I18N::Collate;        # use I18N::Collate;
   use I18N::JExt;           # use I18N::JExt;
@@ -607,6 +665,7 @@ WW[̃t@C /Perl/site/lib/Sjis ɃRs[ 'use utf8;'
   use Japanese;             # use Japanese;
   no utf8;                  # no utf8;
   no bytes;                 # no bytes;
+  no charnames;             # no charnames;
   no I18N::Japanese;        # no I18N::Japanese;
   no I18N::Collate;         # no I18N::Collate;
   no I18N::JExt;            # no I18N::JExt;
@@ -786,6 +845,17 @@ oO񍐁Apb`}܂B
  
     ɂȂA$& ̑Ɏgp邱Ƃł܂B
 
+ 邢͈ȉ̕@܂B
+
+  -------------------------------------------------
+  ϐ   ֖@
+  -------------------------------------------------
+  $`     substr(Ώە, 0, $-[0])
+  $&     substr(Ώە, $-[0], $+[0], - $-[0])
+  $'     substr(Ώە, $+[0])
+  -------------------------------------------------
+  uڐ K\ 2 P.349 7.9.3.4 }b`ORs[v
+
 =item * K\Kp镶̒̏
 
     L̂ƂAGXP[v̐K\ɂ̓}`oCgAJ[Ô
@@ -799,6 +869,12 @@ oO񍐁Apb`}܂B
     \G can't treat over 32,767 octets
     http://bugs.activestate.com/show_bug.cgi?id=89792
 
+=item * K\̏Cq /a /d /l /u
+
+    ̃\tgEFÃRZvg͕̕𓯎ɗpȂ悤ɂ
+    ƂłB]ďCq /a /d /l /u T|[g܂B
+    \d ͐̂ [0-9] Ӗ܂B
+
 =back
 
 =head1 
@@ -840,74 +916,76 @@ VtgJISɂẮA16i 0x81`0x9F ܂ 0xE0`0xEF ͈̔͂INebg
 
 =head1 EBLyfBAɂuShift_JISv̒`
 
-Shift_JIS (2009.09.17 14:00:00 JST). In Wikipedia: The Free Encyclopedia.
+Shift_JIS (2011.10.27 00:00:00 JST). In Wikipedia: The Free Encyclopedia.
 Retrieved from
 http://ja.wikipedia.org/wiki/Shift_JIS
 
 oT: t[SȎTwEBLyfBA(Wikipedia)x
 
-Shift_JIS(IANAւ̓o^Bǂݕ́wVtgWXx)́Aݑ̃p\R
-{\߂ɎgĂ镶R[hłBƎ̃R[hgĂ
-A݂͕WĂJIS X 0208̕1ŋK肵ĂB
-
-Microsoft̊ex_Shift_JIS̈ɂẮwMicrosoftR[hy[
-W932xQƁBMac OS鈟ɂẮwMacJapanesexQƁB
+Shift_JISiVtgWXj́Aݑ̃p\R̃t@Cœ{\
+ɎgĂ镶R[hłBĂ̓x_[ɂƎg܂ޕR[h
+Qɑ΂BȖ̂łA݂͕WJIS X 0208̕1ŋK肳
+ĂBuShift_JISvIANAɂo^łB
 
 Shift_JIS̒a
-1980NAp\Rp16rbgCPU̕y܂āA\\ȃn[hEF
-Ap\RXƔꂽB̂߁Ap\Rp̕
-͍ĂB
 
-Shift_JISuVtgJISR[hvƌĂŕW(R[h)̖ʂ݂̂
-lc_邪Ał͕̖ʂɏœ_𓖂ĂB
+1980NAp\Rp16rbgCPU̕y܂āA≼\\ȃn[
+hEFAp\RXƔꂽB̂߁A{\ł镶
+͍ĂiShift_JISuVtgJISR[hvƌĂŕ
+WiR[hj̖ʂ݂̂lc_邪Ał͕̖ʂ
+œ_𓖂ĂjB
 
-̕ɂ́AsĂ悭pĂJIS C 6220(݂JIS X 0201)
-8rbg(ȉupEpJiv)ƁAJIS C 6226(݂JIS X 0208A
-ȉuv)̗WA\悤ƂBt@C̑傫AԂ
-Zk}邽߃GXP[vV[PXȂō݉\ɂ邱ƂlĂB
+Shift_JIS̐݌v҂́AsĂ悭pĂJIS C 6220
+i݂JIS X 0201j8rbgiȉupEpJivjƁAJIS C 6226
+i݂JIS X 0208Aȉuvj̗W\悤ƂB܂At@
+C̑傫⏈Ԃ̒Zk}邽߁AGXP[vV[PXȂō݉\
+邱Ƃ}B
 
 JIS C 6220JIS C 62262͂ƂɁAISO 2022ŕW؂ւėp
-݌vBISO 2022ɂƂÂł́ApApJiA
-ꂼA8rbgԂ̒GL/GRƂ̈1(2)g
-Ƃŕ\łBpƊ2GXP[vV[PXȂō݂
-ȂApGLAGRɊ蓖Ă@BEUC-JṔA悻̂悤
-ɎĂB
+݌vBISO 2022ɊÂł́ApApJiA͂
+A8rbgԂ̒GL/GRƂ̈1i2jgƂ
+\łBpƊ2GXP[vV[PXȂō݂ȂA
+pGLAGRɊ蓖Ă@BEUC-JṔA悻̂悤Ɏ
+ĂB
 
-Ap\Rł͂łɁAJIS X 02018rbgA܂AGLɉpAGR
-PoCgJ^Ji(pJ^Ji)蓖Ă邱ƂyĂBpƂPoC
-gJ^Ji2𓮂Ƃ́ǍɂȂ邽ߔKvB
-̂߁AISO 2022̘g̗̈Ɋ݂邱Ƃ͍̂łB
+Ap\Rł͂łɁAJIS X 02018rbgA܂GLɉpAGR1o
+CgJ^JiipJ^Jij蓖ĂyĂBp1oCgJ
+^Ji2𓮂Ƃ́ǍɂȂ邽ߔKvB
+߁AISO 2022̘g̗̈Ɋ݂邱Ƃ͍B
 
-1982NA̕ʒu𕡎GɈړ(Vtg)AԂ̌Ԃɉ
-ShiftJISaB邽߂ɂ́A1oCgڂƂāAISO 2022
-ɂGR(A1(16)-FE(16))̈31cĂgp̈ɂ킦AISO 2022
-ɂĔgpCR(80(16)-9F(16))̈gp邱ƂƂBAGL
-(21(16)-7E(16))̈ɂẮAJIS X 0201̋Lɓ镔͋ɗ͔B
-2oCgڂɂISO 2022Ƃ͈قȂApEpJiɎgpς݂̗̈
-܂ށAGLACRAGRɂë̂قڑSĂgKvB
+1982NA̕ʒu𕡎GɈړiVtgjAԂ̌Ԃɉ
+Shift JISaB邽߂ɂ́A1oCgڂƂāAISO 2022
+ɂGRiA1(16)-FE(16)j̈31cĂgp̈ɉAISO 2022
+ĔgpCRi80(16)-9F(16)j̈gp邱ƂƂBAGLi21(16)
+-7E(16)j̈ɂẮAJIS X 0201̋Lɓ镔͋ɗ͔B2oC
+gڂɂ́AISO 2022Ƃ͈قȂApEpJiɎgpς݂̗̈܂ށAGLA
+CRAGRɂë̂قڑSĂgKvB
 
-}CN\tg({@l)̌Ð식ɂƁAShift_JIS̐ɂ́AAX
-L[A}CN\tg()AOHd@A}CN\tgEFAEA\VGCcA
-fW^T[`()ւAɃAXL[̎RǑSƂȂč쐬
-̂ƂBɑ΂ِƂāAsẅF́A}CN\t
-gEFAEA\VGCcƎOHd@݂̂̋JƎ咣ĂBR{l̔
-ɂ͎̓PƂ锭ĂB
+}CN\tgi{@lj̌Ð식ɂƁAShift_JIS̐ɂ́AAX
+L[A}CN\tgiājAOHd@A}CN\tgEFAEA\VGCcAf
+W^T[`iājւAɃAXL[̎RǑSƂȂč쐬
+̂ƂBɑ΂ِƂāAsẅF́A}CN\
+tgEFAEA\VGCcƎOHd@݂̂̋JƎ咣ĂAR{l
+̔ɂ͎P񂷂锭ĂB܂ÂLife with UNIX
+󏑁iISBN 4-7561-0783-4j́uUNIXlTv|ŉMip. 45jŁA[
+OɁuMSR[h̍҂̈lvƂЉĂB
 
 Shift_JIS̕W
+
 Shift_JIŚAWƂ̗̕܂ތ̖
 邽߂̋ZpłB䂦AJIS X 0208̕W𗘗pĂ͂̂́A
 ISO 2022̕̕j͈̔͂̊OɂB
 
-ȂA݂ł́AJIS X 0208:1997̕1ɂāuVtg\vƂ
-OŁAdl`ĂB́Aft@NgX^_[hƂȂĂZp
-ɂĂ͏oƂAƂWĂ܂ƂӐ}{HƕW
+݂ł́AJIS X 0208:1997̕1ɁAuVtg\vƂO
+dl`ĂB́Aft@NgX^_[hƂȂĂZpɂ
+͏oƂAƂWĂ܂ƂӐ}{HƕW
  (JISC) ɂĂ̂ƂłB
 
 JIS X 0208̊gKiłJIS X 0213ł́A2000N̏łŕ1Ƃ
 Shift_JISX0213߂ꂽB2004N10ǉɔāAShift_JIS-2004
 Ɩ̂ύXꂽB
 
-IANAuShift_JISvƂOœo^ĂB
+IANAłuShift_JISvƂO蓖ĂĂB
 
 _ƌ_
 
@@ -916,55 +994,55 @@ _
    \łB
 2. {ɂẮAMS-DOSœ{pR[hƂč̗pĈȗAp\
    RɂĈ|IȕyxȂ̕ɔׂăf[^
-   \ (AWɂĂ͎x_JIS X 0208ŋK肳
-   Ȃ@ˑ̊g{Ă邱ƂAgɊւĂ
-   f[^\Ⴂ)B
+   \B
 
 _
 1. pJî߂̗̈mۂ֌WAR[hV[NGX_ԍ́uv
    ̋؂ł͂ȂӏŕfĂB̂߁AR[hԍZŋ߂ۂ
    ώGȏKvłB
 2. 2oCgڂ80(16)(ASCIĨR[ḧ)B̂߁A̋؂
-   ɎԂBt@CAd̐擪當R[h肷ꍇ͂悢A
-   납當R[h̔悤ƎvƁAň̏ꍇA擪܂łǂȂ
-   ȂƂ邽߁AvO̍ɍHvKvɂȂB܂A̗
-   Ɋ܂܂ꕔ̈̂̕߁A}`oCgEUC-JPAUTF-8ȂǂAv
-   O~ÖB
+   ɎԂBt@Cd̐擪當R[h̔ꍇ͂悢
+   A납画悤ƂƁAň̏ꍇA擪܂łǂȂƂȂ
+   Ƃ邽߁AvO̍ɍHvKvɂȂB܂Ä̗Ɋ܂
+   ꕔ̈̂̕߁A}`oCgEUC-JPAUTF-8ȂǂɔׁAvO
+   ~ÖiQƁjB
 3. JIS⏕\łȂB⏕̕Shift_JIS̃R[ho^
    ܂ȂB
+4. WɂĂ͎x_JIS X 0208ŋK肳ĂȂ@ˑ̊g
+   {Ă邱ƂAgɊւĂ̓f[^\ႢB
 
 2oCgڂ5CɂȂ肤邱Ƃɂ
 
-Shift_JISł́Au\vu\vȂǈꕔ̎2oCgڂɁA5C(16)(Shift_JISł
-LAASCIIȂǂł̓obNXbV)gpĂB̃vO~O
- (CAPerlABourne ShellȂǑ) ł́A5C(16)GXP[vƂ
-BāA\[XR[h╶f[^̏ɂShift_JISz肵
-ȂvO~Oł͖肪NB̖́A悤2oCgڂ
-͈͂5C(16)܂Big5A܂ł͂邪GBKȂǂ̕R[hłB
+Shift_JISł́Au\vu\vȂǈꕔ̎2oCgڂɁA5C(16)iShift_JISł́
+LAASCIIȂǂł̓obNXbVjgpĂB̃vO~O
+ (CAPerlABourne ShellȂǑ) ł́A5C(16)GXP[vƂĂB
+āA\[XR[h╶f[^̏ɂShift_JISz肵ĂȂv
+O~Oł͖肪NB̖́A悤2oCgڂ͈̔͂5C(16)
+܂Big5A܂ł͂邪GBKȂǂ̕R[hłB
 
 ܂A5C(16)ȊOɂĂގ̖肪邱ƂBƂ΁AUnix
-MS-DOSȂǂ̃VF7C(16) (Shift_JISASCIIł̓o[eBJo[) ܂
-(|A|A|A|A|A|A|Acc)t@CɎgp悤ƂƁA
-pCvLƔFAɃt@C쐬ȂAǂݍ݂sǂ
-Ȃ肷邱ƂB
+MS-DOSȂǂ̃VF7C(16) (Shift_JISASCIIł̓o[eBJo[) ܂ޕ
+i|A|A|A|A|A|A|Accjt@CɎgp悤ƂƁApCv
+LƔFAɃt@C쐬ȂAǂݍ݂sǂɂȂ
+邱ƂB
 
 ݂łAVOoCgR[hΉ̃\tgEFAShift_JISŎgp
 ƁAsȂǂ̓t@C̏Ȃǂɂ΂΂̖肪܂ƂB
-sA2oCgڂ5C(16)̂ƂAߕƌĂсA̒ɂ
-u\vu\vu\vu\vȂǈʂɎgppx̍[1]B
+sA2oCgڂ5C(16)͑ɁuߕvƌĂ΂A̒
+́u\vu\vu\vu\vȂǈʂɎgppx̍܂܂B
 
-̖`Iȕ@ƂāA\[XR[hŜEUCR[hUTF-8Ȃ
-ɕϊĂRpCs肷@B邢́u\\v
-悤2oCgڂ̒OɃGXP[v5C(16)LqAߕ𕶎Ƃ
-FȂǂ̕@(Perl Sjis\tgEFAȂ)Bŋ߂ł́A
-̃vO~OꂪShift_JISɑΉ悤ɂȂ߁AShift_JIS܂
-\[XR[hf[^Ă̖͋NȂȂÃ\tgEFA
-Y𗘗pł͈ˑRA肪܂ƂB
+̖`Iȕ@ƂāA\[XR[hŜEUCR[hUTF-8Ȃǂ
+ϊĂRpCs肷@iFPerl encodingv
+O}jB邢́u\vu\\v̂悤ɁA2oCgڂ̒OɃGXP[v
+5C(16)LqAuߕv𕶎ƂĐF@iFPerl
+Sjis\tgEFAjB邢͕܂͕ƂĈ킸Ώەѓ
+\`𐔒l̔zƂĕϊsA舵ۂɕɕĈ@
+iFPerl EncodeW[jB
 
 
 
-pɂɌƂāAu\ȂvƂ񂪂̌f\tg
-uȂvƉB
+u\ȂvƂ񂪂̌f\tgŁuȂvƕ
+pɂɌB
 
    \         
   8d5c 82ed 82c8 82a2
@@ -996,7 +1074,7 @@ uvƂ̂ƂŃfR[hē͐̕ɖ߂B܂l
   \   8E5C JCRB{\
   \   8F5C 10B
   \   905C AB\
-  \   915C AЁBu]v̈ẂB\
+  \   915C AЁBu]v̈ẂíjB\
   \   925C B\y
   \   935C ͂B\t
   \   945C ̂B\
@@ -1007,7 +1085,7 @@ uvƂ̂ƂŃfR[hē͐̕ɖ߂B܂l
   \   995C ƁABuevّ̈̎
   \   9A5C B\
   \   9B5C B\a(ua̔񏑊)
-  \   9C5C B퐶́uv̋
+  \   9C5C B퐶́uv̐
   \   9D5C B\
   \   9E5C Ȃ̕ʑ
   \   9F5C AA傤B
@@ -1028,48 +1106,54 @@ uvƂ̂ƂŃfR[hē͐̕ɖ߂B܂l
   \   FB5C B
 
 R[hԂɂ镶
-Shift_JIS2oCgR[h̋Ԃ́A1oCg81(16)-9F(16)ȂтE0(16)-FC(16)A
-2oCg40(16)-7E(16)Ȃт80(16)-FC(16)łBāA60~188=11280
-A1oCgR[h158 (Xy[X܂݁ADEL͐)ł邽߁A
-v11438ƂȂB
+
+Shift_JIS2oCgR[h̋Ԃ́A1oCg81(16)-9F(16)ȂтE0(16)-
+FC(16)A2oCg40(16)-7E(16)Ȃт80(16)-FC(16)łBāA
+60~188=11280A1oCgR[h158iXy[X܂݁ADEL͐j
+ł邽߁Av11438ƂȂB
 
 ȂAShift_JIS-2004ł́A2oCg11233A1oCg158̂߁A
 v11391gpĂB
 
 Shift_JISɂuVtgvƂ
+
+Shift JIŚuVtgvƂ́A256~256̕ʂ̒ŕ𕡎G"炷"ƂӖ
+́uVtgvłB
+
 ISO-2022-JP͎wV[PXŊƃAt@xbg؂ւ镄łB
 ܂AEUC-JP͕⏕ƔpJ^JiVOVtgňꎞIɐ؂ւĎg
-łB̕ł́AeW̖ʂVtgR[hɂ
-؂ւ(Vtg)ĂB
-
-ȂAShift_JIŚwVtgxƂ͂̈Ӗł̃Vtgł͂ȂB܂Arbg
-VtǵwVtgxłȂB́wVtgxƂ́A256~256̕ʂ̒ŕ
-G"炷"ƂӖ́wVtgxłB
+łB̕ōsĂAeW̖ʂVtgR[
+hɂĐ؂ւ鑀uVtgvƌĂ΂邪AShift_JIŚuVtgv͂
+Ƃ͈قȂӖłB܂rbg炷irbgVtgjƂقȂB
 
 Shift_JISƋ_ԍ
-Shift_JIS̑Ώۂɂ镶ZbǵAJIS X 0208łB̕
-Wɂ́A_ԍƂTO݂B́A94~94̕\̍sƗ̔ԍ
-̑głB
 
-Shift_JISł́A8140(16)-FCFC(16)Ƃ悤ɁAJIS X 0208Ƃ͂܂
-R[ȟnł邪AJIS X 0208vZɂό`̂ł邽߁A_ԍ
-pĕ̃R[h|CgwƂBeɂẮAJIS X 0208
-1`94ƓłBA@ˑł́AVtgJIS̕ԂtA
-94̉ɂ120܂łgĂ邩̂悤ɈƂB95ȏ
-́AISO/IEC 2022ɑJIS X 0208̍\ł݂͑Ȃ̂ŁA{͂B
+Shift_JIS̑Ώۂɂ镶ẂAJIS X 0208łB̕W
+ɂ́A_ԍƂTO݂B́A94~94̕\̍sƗ̔ԍ̑g
+łB
+
+Shift_JISł́A8140(16)-FCFC(16)Ƃ悤ɁAJIS X 0208Ƃ͂܂R[
+ȟnł邪AJIS X 0208vZɂό`̂ł邽߁A_ԍp
+̃R[h|CgwƂBeɂẮAJIS X 02081`94
+ƓłBA@ˑł́AVtgJIS̕ԂtA94
+ɂ120܂łgĂ邩̂悤ɈƂB95ȏ́A
+ISO/IEC 2022ɑJIS X 0208̍\ł݂͑Ȃ̂ŁA{͂B
 x_Ǝ̔ȊTOłBȂAJIS X 0213̋Kïꕔł
-Shift_JISX0213\ɂẮA1oCgF0(16)ȍ~2ʂ̕Ɋ蓖
-ĂASƂ悤ȑ݂Ȃԍ͓oꂵȂB
+Shift_JISX0213\ɂẮA1oCgF0(16)ȍ~2ʂ̕Ɋ蓖Ă
+ASƂ悤ȑ݂Ȃԍ͓oꂵȂB
 
 ux-sjisvƁuMS_Kanjiv
+
 ux-sjisvƁuMS_Kanjiv͂ƂɁAHTMLhLǵucharsetv̎w
 uShift_JISv̕ʖƂĎgƂoB
 
-ux-sjisvIANAɁuShift_JISvƂOo^OɁANetscape Navigator 2.0
-ɂĎgĂGR[fBO̎wqłBꕔHTML\tg
+ux-sjisvIANAɁuShift_JISvƂOo^OɁANetscape Navigator
+2.0ɂĎgĂGR[fBO̎wqłBꕔHTML\tg
 ł̎wqgݍŎgĂB̂ߔF\ȃuEU邪A
 uShift_JISvɏ邱Ƃ𐄏ĂB
 
+uMS_KanjivIANAɂuShift_JISv̕ʖƂĊ蓖ĂĂB
+
 
 =head1 ̃\tgEFAł "ShiftJIS"
 
@@ -1375,19 +1459,6 @@ V@ŖƂȂĂ邱Ƃ UTF8 tO͎ۂ̕̕ƈvȂ
 Ő̂̕@ɖ߂ƂɂāAǂ̂悤ɉ̂ Programming Perl, 3rd ed.
 (M vO~OPerl 3) 402y[Wxp܂傤B
 
-  Sjis\tgEFApɂ񏈗f
- 
-    +-----------------------------------+
-    |           Octet Strings           | oCif[^
-    +-----------------------------------+
-    |         Character Strings         | eLXgf[^
-    +-----------------------------------+
-    |      ASCII Compatible Encoding    | ShiftJIS Ȃ
-    +-----------------------------------+
-              (UTF8tOȂ)
- 
-    ̐}ɈӖ͂Ȃ߁AoKv܂B
-
 zIɂ́Aȉ5̃S[悤ƍlĂ܂B
 
 =over 2
@@ -1558,6 +1629,7 @@ vO~O񋟂܂B
  Perl\[XLbg - UNIX
  Futato, Irving, Jepson, Patwardhan, Siever , CG[[x R{ _ 
  ISBN4-900900-65-6
+ http://www.oreilly.co.jp/out/presuni/
 
  {񏈗
  Understanding Japanese Information Processing
@@ -1565,6 +1637,7 @@ vO~O񋟂܂B
  1995N8 s
  496y[W
  ISBN 4-89052-708-7
+ http://www.fukkan.com/vote.php3?no=4293
 
  CJKV؉z񏈗
  Chinese, Japanese, Korean & Vietnamese Computing
@@ -1611,7 +1684,7 @@ vO~O񋟂܂B
  1993N8
  172y[W
  T1008901080816 G08901-8
- http://ascii.asciimw.jp/books/magazines/unix.shtml
+ http://ascii.asciimw.jp/books/books/detail/978-4-7561-5008-0.shtml
 
  MacPerl
  Vicki Brown, Chris Nandor , ()RXEvlbg 
@@ -1666,9 +1739,10 @@ vO~O񋟂܂B
 
  ̑ a, jcode.pl
  ftp://ftp.iij.ad.jp/pub/IIJ/dist/utashiro/perl/
+ http://log.utashiro.com/pub/2006/07/jkondo_a580.html
 
  Jeffrey E. F. Friedl, Mastering Regular Expressions
- http://www.oreilly.com/catalog/regex/index.html
+ http://regex.info/
 
  A ms, Shift-JISeLXg𐳂
  http://homepage1.nifty.com/nomenclator/perl/shiftjis.htm
@@ -1683,7 +1757,7 @@ vO~O񋟂܂B
  http://www.rakunet.org/tsnet/TSabc/18/546.html
 
  a G, WindowsPerl 5.8/5.10gȂ
- http://www.aritia.org/hizumi/perl/perlwin.html
+ http://www.aritia.jp/hizumi/perl/perlwin.html
 
  ˖{ q, Perl/Windowsł̃t@CpX
  http://digit.que.ne.jp/work/wiki.cgi?Perl%E3%83%A1%E3%83%A2%2FWindows%E3%81%A7%E3%81%AE%E3%83%95%E3%82%A1%E3%82%A4%E3%83%AB%E3%83%91%E3%82%B9
@@ -1710,7 +1784,8 @@ vO~O񋟂܂B
 
   e, Encode W[
  http://search.cpan.org/dist/Encode/
- http://www.dan.co.jp/~dankogai/yapcasia2006/slide.html
+ http://www.archive.org/details/YAPCAsia2006TokyoPerl58andUnicodeMythsFactsandChanges ()
+ http://yapc.g.hatena.ne.jp/jkondo/ ()
 
  Juerd, Perl Unicode Advice
  http://juerd.nl/site.plp/perluniadvice
